import java.awt.*;
import java.applet.*;
import java.util.*;

// This class is a loader that runs one or more applets as standalone
// applications. It is similar to the appletviewer except it doesn't
// require an HTML page.
// You can add the following parameters to the applet name:
// height=xxx  set the height of the applet
// width=xxx set the width of the applet
// name=xxx set the name of the applet (Default is class name)
// The parameters can be given immediately following an applet name,
// separated by commas. For example:
// java RunApplet applet1,height=300,width=200,name=number1 applet2

public class RunApplet extends Object
{

// Creates the frame, sets the stub, starts the applet

    public static void startApplet(Applet applet, int width, int height,
        String name, String startDir)
    {

// Create the applet's frame
        Frame appletFrame = new Frame(name);

// Allow room for the frame's borders
        appletFrame.resize(width+10, height+20);

// Use a grid layout to maximize the applet's size
        appletFrame.setLayout(new GridLayout(1, 0));

// Add the applet to the frame
        appletFrame.add(applet);

// Show the frame, which makes sure all the graphics info is loaded
// for the applet to use.

        appletFrame.show();

// Create and set the stub
        AppletStub stub = new RunAppletStub(appletFrame, applet, name,
            startDir);
        applet.setStub(stub);

// initialize the applet
        applet.init();

// Make sure the frame shows the applet
        appletFrame.validate();

// Start up the applet
        applet.start();

    }

    public static void main(String[] args)
    {
        if (args.length < 1) {
            System.err.println("Please supply the applet name.");
        }

// For each arg, parse out the applet class name and other params

        for (int i=0; i < args.length; i++) {
            StringTokenizer tokenizer = new StringTokenizer(
                args[i], ",");
            
            String className = null;

// default to 300x200 frame
            int width = 300;
            int height = 200;

            String name = null;
            String startDir = null;

            while (tokenizer.hasMoreTokens()) {
                String token = tokenizer.nextToken();

// Look for width= parameter, if found, get the integer. If there's
// an error parsing the int, just ignore it

                if (token.startsWith("width=")) {
                    try {
                        width = Integer.valueOf(
                            token.substring(6)).
                            intValue();
                    } catch (Exception ignore) {
                    }

// Look for the height parameter, ignore if there's an error
                } else if (token.startsWith("height=")) {
                    try {
                        height = Integer.valueOf(
                            token.substring(7)).
                            intValue();
                    } catch (Exception ignore) {
                    }

// Look for the optional applet name
                } else if (token.startsWith("name=")) {
                    name = token.substring(5);

// Normally, you just give the applet's class name in the parameter
// list, but if you like, you can be more specific and say
// applet=xxx. 
                } else if (token.startsWith("applet=")) {
                    className = token.substring(7);

// Set the home directory for the applet. If not set, will
// use the current directory (from System property "user.dir")

                } else if (token.startsWith("startdir=")) {
                    startDir = token.substring(9);
                } else {
                    if (className == null) {
                        className = token;
                    } else {
                        System.err.println(
                            "Invalid parameter - "+
                            token);
                    }
                }
            }
                
            if (className == null) {
                System.err.println(
                    "No class name specified in: "+
                    args[i]);
            }
            if (name == null) name = className;

// If no startDir set, use the "user.dir" property

            if (startDir == null) {
                startDir = System.getProperty("user.dir")+"//";
            }

// This little piece of bogosity changes any \'s in the start dir
// to /'s, since the URL classes require /'s.

            StringBuffer buff = new StringBuffer(startDir);
            for (int j=0; j < buff.length(); j++) {
                if (buff.charAt(j) == '\\') {
                    buff.setCharAt(j, '/');
                }
            }

// Convert the string buffer back to a string.
            startDir = new String(buff);

// Load the applet's class
            try {
                Class appletClass = Class.forName(className);
                Applet runme = (Applet) appletClass.
                    newInstance();

// Start the applet
                startApplet(runme, width, height, name,
                    startDir);
            } catch (Exception e) {

// If there's an error, just say which applet had the problem,
// but don't quit.

                System.err.println("Error starting applet - "+
                    args[i]);
                System.err.println(e);
            }
        }
    }
}
